details = {
    "searchcomponentid": "",
    "name": "Related",
    "icon": "fa fa-code-fork",
    "modulename": "",
    "classname": "",
    "type": "related-resources-filter-type",
    "componentpath": "views/components/search/related-resources-filter",
    "componentname": "related-resources-filter",
    "config": {},
}
